==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-69.js <==
dispMUA.arDispMUAAllocation["i"] =
{
  "interfejs www nowej poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "interfejs www poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "ibm lotus domino access for ms outlook" : [ "domino_outlook.png" ] ,
  "internetpost for active platform" : [ "internetpost.png" ] ,
  "internet messaging program" : [ "imp.png" ] ,
  "iskoninternet webmail" : [ "iskon.png" ] ,
  "internet mail service" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "ipx-manager via php" : [ "ipxserver.png" , "http://www.ipx-server.de/" ] ,
  "internet fax, mgcs" : [ "panafax.png" ] ,
  "ics smtp component" : [ "internet_component_suite.png" ] ,
  "inside-intermedia" : [ "inside-intermedia.png" , "http://www.inside-intermedia.de/" ] ,
  "inmail by insite" : [ "inmailinsite.png" ] ,
  "inbox.lv webmail" : [ "inbox_lv.png" , "http://www.inbox.lv/" ] ,
  "i.ua mail system" : [ "i_ua.png" , "http://www.i.ua/" ] ,
  "ipb php mailer" : [ "ipb.png" ] ,
  "ieurop webmail" : [ "ieurop_net.png" , "http://www.ieurop.net/" ] ,
  "interact24.de" : [ "interact24_de.png" , "http://interact24.de/" ] ,
  "inteligo-smtp" : [ "inteligo.png" ] ,
  "inmail insite" : [ "inmailinsite.png" ] ,
  "icompass-mail" : [ "icompass.png" ] ,
  "i-soft/i-tems" : [ "i_tems.png" ] ,
  "i-soft i-tems" : [ "i_tems.png" ] ,
  "it&o-versand" : [ "itando.png" , "http://www.itando.net/versand.htm" ] ,
  "ihug webmail" : [ "ihug.png" , "http://webmail.ihug.co.nz/" ] ,
  "ientrymailer" : [ "ientrymailer.png" ] ,
  "iphone mail" : [ "apple_iphone.png" , "http://www.apple.com/" ] ,
  "incredimail" : [ "incredimail.png" , "http://www.incredimail.com/" ] ,
  "ibr-online" : [ "ibr-online.png" , "http://www.ibr-online.de/" ] ,
  "irfanview" : [ "irfanview.png" ] ,
  "ipod mail" : [ "apple_ipodtouch.png" , "http://www.apple.com/" ] ,
  "inbox.com" : [ "inbox_com.png" , "http://www.inbox.com/" ] ,
  "ilohamail" : [ "iloha_mail.png" ] ,
  "inscribe" : [ "inscribe.png" ] ,
  "i.scribe" : [ "i_scribe.png" ] ,
  "iplanet" : [ "iplanet.png" ] ,
  "inxmail" : [ "inxmail.png" ] ,
  "imp/php" : [ "imp.png" ] ,
  "icewarp" : [ "icewarp.png" , "http://www.icewarp.com/" ] ,
  "icedove" : [ "icedove.png" , "http://packages.debian.org/stable/mail/icedove" ] ,
  "inmail" : [ "inmail_cz.png" , "http://www.inmail.cz/" ] ,
  "igmail" : [ "igmail.png" ] ,
  "i-land" : [ "i-land.png" , "http://www.iland.net/" ] ,
  "is24" : [ "is24.png" , "http://www.immobilienscout24.de/" ] ,
  "imp" : [ "imp.png" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-69.js <==
dispMUA.arDispMUAAllocation["i"] =
{
  "interfejs www nowej poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "interfejs www poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "ibm lotus domino access for ms outlook" : [ "domino_outlook.png" ] ,
  "internetpost for active platform" : [ "internetpost.png" ] ,
  "internet messaging program" : [ "imp.png" ] ,
  "iskoninternet webmail" : [ "iskon.png" ] ,
  "internet mail service" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "ipx-manager via php" : [ "ipxserver.png" , "http://www.ipx-server.de/" ] ,
  "internet fax, mgcs" : [ "panafax.png" ] ,
  "internet anywhere" : [ "internet-anywhere.png" , "http://www.tnsoft.de/" ] ,
  "ics smtp component" : [ "internet_component_suite.png" ] ,
  "inside-intermedia" : [ "inside-intermedia.png" , "http://www.inside-intermedia.de/" ] ,
  "inmail by insite" : [ "inmailinsite.png" ] ,
  "inbox.lv webmail" : [ "inbox_lv.png" , "http://www.inbox.lv/" ] ,
  "i.ua mail system" : [ "i_ua.png" , "http://www.i.ua/" ] ,
  "ipb php mailer" : [ "ipb.png" ] ,
  "ieurop webmail" : [ "ieurop_net.png" , "http://www.ieurop.net/" ] ,
  "interact24.de" : [ "interact24_de.png" , "http://interact24.de/" ] ,
  "inteligo-smtp" : [ "inteligo.png" ] ,
  "inmail insite" : [ "inmailinsite.png" ] ,
  "icompass-mail" : [ "icompass.png" ] ,
  "i-soft/i-tems" : [ "i_tems.png" ] ,
  "i-soft i-tems" : [ "i_tems.png" ] ,
  "it&o-versand" : [ "itando.png" , "http://www.itando.net/versand.htm" ] ,
  "ihug webmail" : [ "ihug.png" , "http://webmail.ihug.co.nz/" ] ,
  "ientrymailer" : [ "ientrymailer.png" ] ,
  "iphone mail" : [ "apple_iphone.png" , "http://www.apple.com/" ] ,
  "incredimail" : [ "incredimail.png" , "http://www.incredimail.com/" ] ,
  "ibr-online" : [ "ibr-online.png" , "http://www.ibr-online.de/" ] ,
  "irfanview" : [ "irfanview.png" ] ,
  "ipod mail" : [ "apple_ipodtouch.png" , "http://www.apple.com/" ] ,
  "inbox.com" : [ "inbox_com.png" , "http://www.inbox.com/" ] ,
  "ilohamail" : [ "iloha_mail.png" ] ,
  "ik mailer" : [ "ikmultimedia.png" , "http://www.ikmultimedia.com/" ] ,
  "ironmail" : [ "securecomputing.png" , "http://www.ciphertrust.com/products/cclass/" ] ,
  "ippbxsrv" : [ "telekom.png" , "http://www.telekom.de/" ] ,
  "inscribe" : [ "inscribe.png" ] ,
  "i.scribe" : [ "i_scribe.png" ] ,
  "iplanet" : [ "iplanet.png" ] ,
  "inxmail" : [ "inxmail.png" ] ,
  "imp/php" : [ "imp.png" ] ,
  "icewarp" : [ "icewarp.png" , "http://www.icewarp.com/" ] ,
  "icedove" : [ "icedove.png" , "http://packages.debian.org/stable/mail/icedove" ] ,
  "inmail" : [ "inmail_cz.png" , "http://www.inmail.cz/" ] ,
  "igmail" : [ "igmail.png" ] ,
  "i-land" : [ "i-land.png" , "http://www.iland.net/" ] ,
  "ispcp" : [ "ispcp.png" , "http://www.isp-control.net/" ] ,
  "is24" : [ "is24.png" , "http://www.immobilienscout24.de/" ] ,
  "imp" : [ "imp.png" ] ,
}
